@@ -14,7 +14,7 @@
 #   limitations under the License.
 
 __author__ = 'Michael Gruber'
-__version__ = '0.1.10'
+__version__ = '0.1.11'
 
 try:
     from importlib import import_module
@@ -68,7 +68,10 @@ class UnitTests(TestCase):
 class FluentTarget(object):
 
     def __init__(self, target):
-        if isinstance(target, ModuleType):
+        if isinstance(target, str):
+            self._target_name = target
+            self._target = import_module(self._target_name)
+        elif isinstance(target, ModuleType):
             self._target_name = target.__name__
             self._target = import_module(self._target_name)
         else:
@@ -319,7 +322,8 @@ class Verifier(FluentTarget):
             if self._times == NEVER:
                 call_entry = call(*arguments, **keyword_arguments)
                 if call_entry in method_of_mock.call_args_list:
-                    raise HasBeenCalledAtLeastOnceError(call_entry)
+                    call_entry_string = str(call_entry).replace('call', self._target_name + '.' + self._attribute_name)
+                    raise HasBeenCalledAtLeastOnceError(call_entry_string)
             else:
                 method_of_mock.assert_called_with(*arguments, **keyword_arguments)
         else:
